﻿using PdfSharp.Pdf;
using PdfSharp.Pdf.IO;
using System;
using System.Collections.Generic;
using System.IO;

namespace PDFSharpMergeConsoleApp
{
    internal class Program
    {
        /// <summary>
        /// Create result directory if not exist.
        /// </summary>
        public static void CreateResultDirectoryForFile(string filePath)
        {
            var dirPath = Path.GetDirectoryName(filePath);
            if (!Directory.Exists(dirPath))
            {
                Directory.CreateDirectory(dirPath);
            }
        }

        /// <summary>
        /// Merge several PDF files into one.
        /// </summary>
        /// <param name="srcPdfFileNames_">input PDF files</param>
        /// <param name="dstPdfFileName_">result PDF file</param>
        public static void Merge(IEnumerable<string> srcPdfFileNames_, string dstPdfFileName_)
        {
            using (var resultPdf = new PdfDocument())
            {
                foreach (var srcFileName in srcPdfFileNames_)
                {
                    using (var sourcePdf = PdfReader.Open(srcFileName, PdfDocumentOpenMode.Import))
                    {
                        foreach (var sourcePage in sourcePdf.Pages)
                        {
                            resultPdf.AddPage(sourcePage);
                        }
                    }
                }

                resultPdf.Save(dstPdfFileName_);
            }
        }

        static void Main(string[] args)
        {
            // Prepare result PDF file path and directory
            string baseDirectory = AppDomain.CurrentDomain.BaseDirectory;
            string resultPdfFilePath = Path.Combine(baseDirectory, "Output\\Result.pdf");
            CreateResultDirectoryForFile(resultPdfFilePath);

            Console.WriteLine($"Result PDF file location: {resultPdfFilePath}");
            
            // Prepare input PDF files
            List<string> inputPdfFilePaths = new List<string>
            {
                Path.Combine(baseDirectory, "TestData\\Test_File_1.pdf"),
                Path.Combine(baseDirectory, "TestData\\Test_File_2.pdf"),
            };

            // Run merge process.
            Merge(inputPdfFilePaths, resultPdfFilePath);

            Console.WriteLine($"Merge process finished. Press any key to exit..");
            Console.ReadLine();
        }
    }
}
